# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InboundAddress(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'chain': 'str',
        'pub_key': 'str',
        'address': 'str',
        'router': 'str',
        'halted': 'bool',
        'global_trading_paused': 'bool',
        'chain_trading_paused': 'bool',
        'chain_lp_actions_paused': 'bool',
        'gas_rate': 'str',
        'gas_rate_units': 'str',
        'outbound_tx_size': 'str',
        'outbound_fee': 'str',
        'dust_threshold': 'str'
    }

    attribute_map = {
        'chain': 'chain',
        'pub_key': 'pub_key',
        'address': 'address',
        'router': 'router',
        'halted': 'halted',
        'global_trading_paused': 'global_trading_paused',
        'chain_trading_paused': 'chain_trading_paused',
        'chain_lp_actions_paused': 'chain_lp_actions_paused',
        'gas_rate': 'gas_rate',
        'gas_rate_units': 'gas_rate_units',
        'outbound_tx_size': 'outbound_tx_size',
        'outbound_fee': 'outbound_fee',
        'dust_threshold': 'dust_threshold'
    }

    def __init__(self, chain=None, pub_key=None, address=None, router=None, halted=None, global_trading_paused=None, chain_trading_paused=None, chain_lp_actions_paused=None, gas_rate=None, gas_rate_units=None, outbound_tx_size=None, outbound_fee=None, dust_threshold=None):  # noqa: E501
        """InboundAddress - a model defined in Swagger"""  # noqa: E501
        self._chain = None
        self._pub_key = None
        self._address = None
        self._router = None
        self._halted = None
        self._global_trading_paused = None
        self._chain_trading_paused = None
        self._chain_lp_actions_paused = None
        self._gas_rate = None
        self._gas_rate_units = None
        self._outbound_tx_size = None
        self._outbound_fee = None
        self._dust_threshold = None
        self.discriminator = None
        if chain is not None:
            self.chain = chain
        if pub_key is not None:
            self.pub_key = pub_key
        if address is not None:
            self.address = address
        if router is not None:
            self.router = router
        self.halted = halted
        if global_trading_paused is not None:
            self.global_trading_paused = global_trading_paused
        if chain_trading_paused is not None:
            self.chain_trading_paused = chain_trading_paused
        if chain_lp_actions_paused is not None:
            self.chain_lp_actions_paused = chain_lp_actions_paused
        if gas_rate is not None:
            self.gas_rate = gas_rate
        if gas_rate_units is not None:
            self.gas_rate_units = gas_rate_units
        if outbound_tx_size is not None:
            self.outbound_tx_size = outbound_tx_size
        if outbound_fee is not None:
            self.outbound_fee = outbound_fee
        if dust_threshold is not None:
            self.dust_threshold = dust_threshold

    @property
    def chain(self):
        """Gets the chain of this InboundAddress.  # noqa: E501


        :return: The chain of this InboundAddress.  # noqa: E501
        :rtype: str
        """
        return self._chain

    @chain.setter
    def chain(self, chain):
        """Sets the chain of this InboundAddress.


        :param chain: The chain of this InboundAddress.  # noqa: E501
        :type: str
        """

        self._chain = chain

    @property
    def pub_key(self):
        """Gets the pub_key of this InboundAddress.  # noqa: E501


        :return: The pub_key of this InboundAddress.  # noqa: E501
        :rtype: str
        """
        return self._pub_key

    @pub_key.setter
    def pub_key(self, pub_key):
        """Sets the pub_key of this InboundAddress.


        :param pub_key: The pub_key of this InboundAddress.  # noqa: E501
        :type: str
        """

        self._pub_key = pub_key

    @property
    def address(self):
        """Gets the address of this InboundAddress.  # noqa: E501


        :return: The address of this InboundAddress.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this InboundAddress.


        :param address: The address of this InboundAddress.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def router(self):
        """Gets the router of this InboundAddress.  # noqa: E501


        :return: The router of this InboundAddress.  # noqa: E501
        :rtype: str
        """
        return self._router

    @router.setter
    def router(self, router):
        """Sets the router of this InboundAddress.


        :param router: The router of this InboundAddress.  # noqa: E501
        :type: str
        """

        self._router = router

    @property
    def halted(self):
        """Gets the halted of this InboundAddress.  # noqa: E501

        Returns true if trading is unavailable for this chain, either because trading is halted globally or specifically for this chain  # noqa: E501

        :return: The halted of this InboundAddress.  # noqa: E501
        :rtype: bool
        """
        return self._halted

    @halted.setter
    def halted(self, halted):
        """Sets the halted of this InboundAddress.

        Returns true if trading is unavailable for this chain, either because trading is halted globally or specifically for this chain  # noqa: E501

        :param halted: The halted of this InboundAddress.  # noqa: E501
        :type: bool
        """
        if halted is None:
            raise ValueError("Invalid value for `halted`, must not be `None`")  # noqa: E501

        self._halted = halted

    @property
    def global_trading_paused(self):
        """Gets the global_trading_paused of this InboundAddress.  # noqa: E501

        Returns true if trading is paused globally  # noqa: E501

        :return: The global_trading_paused of this InboundAddress.  # noqa: E501
        :rtype: bool
        """
        return self._global_trading_paused

    @global_trading_paused.setter
    def global_trading_paused(self, global_trading_paused):
        """Sets the global_trading_paused of this InboundAddress.

        Returns true if trading is paused globally  # noqa: E501

        :param global_trading_paused: The global_trading_paused of this InboundAddress.  # noqa: E501
        :type: bool
        """

        self._global_trading_paused = global_trading_paused

    @property
    def chain_trading_paused(self):
        """Gets the chain_trading_paused of this InboundAddress.  # noqa: E501

        Returns true if trading is paused for this chain  # noqa: E501

        :return: The chain_trading_paused of this InboundAddress.  # noqa: E501
        :rtype: bool
        """
        return self._chain_trading_paused

    @chain_trading_paused.setter
    def chain_trading_paused(self, chain_trading_paused):
        """Sets the chain_trading_paused of this InboundAddress.

        Returns true if trading is paused for this chain  # noqa: E501

        :param chain_trading_paused: The chain_trading_paused of this InboundAddress.  # noqa: E501
        :type: bool
        """

        self._chain_trading_paused = chain_trading_paused

    @property
    def chain_lp_actions_paused(self):
        """Gets the chain_lp_actions_paused of this InboundAddress.  # noqa: E501

        Returns true if LP actions are paused for this chain  # noqa: E501

        :return: The chain_lp_actions_paused of this InboundAddress.  # noqa: E501
        :rtype: bool
        """
        return self._chain_lp_actions_paused

    @chain_lp_actions_paused.setter
    def chain_lp_actions_paused(self, chain_lp_actions_paused):
        """Sets the chain_lp_actions_paused of this InboundAddress.

        Returns true if LP actions are paused for this chain  # noqa: E501

        :param chain_lp_actions_paused: The chain_lp_actions_paused of this InboundAddress.  # noqa: E501
        :type: bool
        """

        self._chain_lp_actions_paused = chain_lp_actions_paused

    @property
    def gas_rate(self):
        """Gets the gas_rate of this InboundAddress.  # noqa: E501

        The minimum fee rate used by vaults to send outbound TXs. The actual fee rate may be higher. For EVM chains this is returned in gwei (1e9).  # noqa: E501

        :return: The gas_rate of this InboundAddress.  # noqa: E501
        :rtype: str
        """
        return self._gas_rate

    @gas_rate.setter
    def gas_rate(self, gas_rate):
        """Sets the gas_rate of this InboundAddress.

        The minimum fee rate used by vaults to send outbound TXs. The actual fee rate may be higher. For EVM chains this is returned in gwei (1e9).  # noqa: E501

        :param gas_rate: The gas_rate of this InboundAddress.  # noqa: E501
        :type: str
        """

        self._gas_rate = gas_rate

    @property
    def gas_rate_units(self):
        """Gets the gas_rate_units of this InboundAddress.  # noqa: E501

        Units of the gas_rate.  # noqa: E501

        :return: The gas_rate_units of this InboundAddress.  # noqa: E501
        :rtype: str
        """
        return self._gas_rate_units

    @gas_rate_units.setter
    def gas_rate_units(self, gas_rate_units):
        """Sets the gas_rate_units of this InboundAddress.

        Units of the gas_rate.  # noqa: E501

        :param gas_rate_units: The gas_rate_units of this InboundAddress.  # noqa: E501
        :type: str
        """

        self._gas_rate_units = gas_rate_units

    @property
    def outbound_tx_size(self):
        """Gets the outbound_tx_size of this InboundAddress.  # noqa: E501

        Avg size of outbound TXs on each chain. For UTXO chains it may be larger than average, as it takes into account vault consolidation txs, which can have many vouts  # noqa: E501

        :return: The outbound_tx_size of this InboundAddress.  # noqa: E501
        :rtype: str
        """
        return self._outbound_tx_size

    @outbound_tx_size.setter
    def outbound_tx_size(self, outbound_tx_size):
        """Sets the outbound_tx_size of this InboundAddress.

        Avg size of outbound TXs on each chain. For UTXO chains it may be larger than average, as it takes into account vault consolidation txs, which can have many vouts  # noqa: E501

        :param outbound_tx_size: The outbound_tx_size of this InboundAddress.  # noqa: E501
        :type: str
        """

        self._outbound_tx_size = outbound_tx_size

    @property
    def outbound_fee(self):
        """Gets the outbound_fee of this InboundAddress.  # noqa: E501

        The total outbound fee charged to the user for outbound txs in the gas asset of the chain.  # noqa: E501

        :return: The outbound_fee of this InboundAddress.  # noqa: E501
        :rtype: str
        """
        return self._outbound_fee

    @outbound_fee.setter
    def outbound_fee(self, outbound_fee):
        """Sets the outbound_fee of this InboundAddress.

        The total outbound fee charged to the user for outbound txs in the gas asset of the chain.  # noqa: E501

        :param outbound_fee: The outbound_fee of this InboundAddress.  # noqa: E501
        :type: str
        """

        self._outbound_fee = outbound_fee

    @property
    def dust_threshold(self):
        """Gets the dust_threshold of this InboundAddress.  # noqa: E501

        Defines the minimum transaction size for the chain in base units (sats, wei, uatom). Transactions with asset amounts lower than the dust_threshold are ignored.  # noqa: E501

        :return: The dust_threshold of this InboundAddress.  # noqa: E501
        :rtype: str
        """
        return self._dust_threshold

    @dust_threshold.setter
    def dust_threshold(self, dust_threshold):
        """Sets the dust_threshold of this InboundAddress.

        Defines the minimum transaction size for the chain in base units (sats, wei, uatom). Transactions with asset amounts lower than the dust_threshold are ignored.  # noqa: E501

        :param dust_threshold: The dust_threshold of this InboundAddress.  # noqa: E501
        :type: str
        """

        self._dust_threshold = dust_threshold

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InboundAddress, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InboundAddress):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class StreamingStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'interval': 'int',
        'quantity': 'int',
        'count': 'int'
    }

    attribute_map = {
        'interval': 'interval',
        'quantity': 'quantity',
        'count': 'count'
    }

    def __init__(self, interval=None, quantity=None, count=None):  # noqa: E501
        """StreamingStatus - a model defined in Swagger"""  # noqa: E501
        self._interval = None
        self._quantity = None
        self._count = None
        self.discriminator = None
        self.interval = interval
        self.quantity = quantity
        self.count = count

    @property
    def interval(self):
        """Gets the interval of this StreamingStatus.  # noqa: E501

        how often each swap is made, in blocks  # noqa: E501

        :return: The interval of this StreamingStatus.  # noqa: E501
        :rtype: int
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this StreamingStatus.

        how often each swap is made, in blocks  # noqa: E501

        :param interval: The interval of this StreamingStatus.  # noqa: E501
        :type: int
        """
        if interval is None:
            raise ValueError("Invalid value for `interval`, must not be `None`")  # noqa: E501

        self._interval = interval

    @property
    def quantity(self):
        """Gets the quantity of this StreamingStatus.  # noqa: E501

        the total number of swaps in a streaming swaps  # noqa: E501

        :return: The quantity of this StreamingStatus.  # noqa: E501
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this StreamingStatus.

        the total number of swaps in a streaming swaps  # noqa: E501

        :param quantity: The quantity of this StreamingStatus.  # noqa: E501
        :type: int
        """
        if quantity is None:
            raise ValueError("Invalid value for `quantity`, must not be `None`")  # noqa: E501

        self._quantity = quantity

    @property
    def count(self):
        """Gets the count of this StreamingStatus.  # noqa: E501

        the amount of swap attempts so far  # noqa: E501

        :return: The count of this StreamingStatus.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this StreamingStatus.

        the amount of swap attempts so far  # noqa: E501

        :param count: The count of this StreamingStatus.  # noqa: E501
        :type: int
        """
        if count is None:
            raise ValueError("Invalid value for `count`, must not be `None`")  # noqa: E501

        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StreamingStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StreamingStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PlannedOutTx(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'chain': 'str',
        'to_address': 'str',
        'coin': 'Coin',
        'refund': 'bool'
    }

    attribute_map = {
        'chain': 'chain',
        'to_address': 'to_address',
        'coin': 'coin',
        'refund': 'refund'
    }

    def __init__(self, chain=None, to_address=None, coin=None, refund=None):  # noqa: E501
        """PlannedOutTx - a model defined in Swagger"""  # noqa: E501
        self._chain = None
        self._to_address = None
        self._coin = None
        self._refund = None
        self.discriminator = None
        self.chain = chain
        self.to_address = to_address
        self.coin = coin
        self.refund = refund

    @property
    def chain(self):
        """Gets the chain of this PlannedOutTx.  # noqa: E501


        :return: The chain of this PlannedOutTx.  # noqa: E501
        :rtype: str
        """
        return self._chain

    @chain.setter
    def chain(self, chain):
        """Sets the chain of this PlannedOutTx.


        :param chain: The chain of this PlannedOutTx.  # noqa: E501
        :type: str
        """
        if chain is None:
            raise ValueError("Invalid value for `chain`, must not be `None`")  # noqa: E501

        self._chain = chain

    @property
    def to_address(self):
        """Gets the to_address of this PlannedOutTx.  # noqa: E501


        :return: The to_address of this PlannedOutTx.  # noqa: E501
        :rtype: str
        """
        return self._to_address

    @to_address.setter
    def to_address(self, to_address):
        """Sets the to_address of this PlannedOutTx.


        :param to_address: The to_address of this PlannedOutTx.  # noqa: E501
        :type: str
        """
        if to_address is None:
            raise ValueError("Invalid value for `to_address`, must not be `None`")  # noqa: E501

        self._to_address = to_address

    @property
    def coin(self):
        """Gets the coin of this PlannedOutTx.  # noqa: E501


        :return: The coin of this PlannedOutTx.  # noqa: E501
        :rtype: Coin
        """
        return self._coin

    @coin.setter
    def coin(self, coin):
        """Sets the coin of this PlannedOutTx.


        :param coin: The coin of this PlannedOutTx.  # noqa: E501
        :type: Coin
        """
        if coin is None:
            raise ValueError("Invalid value for `coin`, must not be `None`")  # noqa: E501

        self._coin = coin

    @property
    def refund(self):
        """Gets the refund of this PlannedOutTx.  # noqa: E501

        returns true if the planned transaction has a refund memo  # noqa: E501

        :return: The refund of this PlannedOutTx.  # noqa: E501
        :rtype: bool
        """
        return self._refund

    @refund.setter
    def refund(self, refund):
        """Sets the refund of this PlannedOutTx.

        returns true if the planned transaction has a refund memo  # noqa: E501

        :param refund: The refund of this PlannedOutTx.  # noqa: E501
        :type: bool
        """
        if refund is None:
            raise ValueError("Invalid value for `refund`, must not be `None`")  # noqa: E501

        self._refund = refund

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PlannedOutTx, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlannedOutTx):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from xchainpy2_thornode.api.auth_api import AuthApi
from xchainpy2_thornode.api.bank_api import BankApi
from xchainpy2_thornode.api.block_api import BlockApi
from xchainpy2_thornode.api.borrowers_api import BorrowersApi
from xchainpy2_thornode.api.clout_api import CloutApi
from xchainpy2_thornode.api.export_api import ExportApi
from xchainpy2_thornode.api.health_api import HealthApi
from xchainpy2_thornode.api.invariants_api import InvariantsApi
from xchainpy2_thornode.api.liquidity_providers_api import LiquidityProvidersApi
from xchainpy2_thornode.api.mimir_api import MimirApi
from xchainpy2_thornode.api.network_api import NetworkApi
from xchainpy2_thornode.api.nodes_api import NodesApi
from xchainpy2_thornode.api.pool_slip_api import PoolSlipApi
from xchainpy2_thornode.api.pools_api import PoolsApi
from xchainpy2_thornode.api.queue_api import QueueApi
from xchainpy2_thornode.api.quote_api import QuoteApi
from xchainpy2_thornode.api.rune_pool_api import RUNEPoolApi
from xchainpy2_thornode.api.savers_api import SaversApi
from xchainpy2_thornode.api.secured_asset_api import SecuredAssetApi
from xchainpy2_thornode.api.secured_assets_api import SecuredAssetsApi
from xchainpy2_thornode.api.streaming_swap_api import StreamingSwapApi
from xchainpy2_thornode.api.tss_api import TSSApi
from xchainpy2_thornode.api.thornames_api import ThornamesApi
from xchainpy2_thornode.api.trade_account_api import TradeAccountApi
from xchainpy2_thornode.api.trade_accounts_api import TradeAccountsApi
from xchainpy2_thornode.api.trade_unit_api import TradeUnitApi
from xchainpy2_thornode.api.trade_units_api import TradeUnitsApi
from xchainpy2_thornode.api.transactions_api import TransactionsApi
from xchainpy2_thornode.api.vaults_api import VaultsApi



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MsgSwap(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'tx': 'Tx',
        'target_asset': 'str',
        'destination': 'str',
        'trade_target': 'str',
        'affiliate_address': 'str',
        'affiliate_basis_points': 'str',
        'signer': 'str',
        'aggregator': 'str',
        'aggregator_target_address': 'str',
        'aggregator_target_limit': 'str',
        'order_type': 'str',
        'stream_quantity': 'int',
        'stream_interval': 'int'
    }

    attribute_map = {
        'tx': 'tx',
        'target_asset': 'target_asset',
        'destination': 'destination',
        'trade_target': 'trade_target',
        'affiliate_address': 'affiliate_address',
        'affiliate_basis_points': 'affiliate_basis_points',
        'signer': 'signer',
        'aggregator': 'aggregator',
        'aggregator_target_address': 'aggregator_target_address',
        'aggregator_target_limit': 'aggregator_target_limit',
        'order_type': 'order_type',
        'stream_quantity': 'stream_quantity',
        'stream_interval': 'stream_interval'
    }

    def __init__(self, tx=None, target_asset=None, destination=None, trade_target=None, affiliate_address=None, affiliate_basis_points=None, signer=None, aggregator=None, aggregator_target_address=None, aggregator_target_limit=None, order_type=None, stream_quantity=None, stream_interval=None):  # noqa: E501
        """MsgSwap - a model defined in Swagger"""  # noqa: E501
        self._tx = None
        self._target_asset = None
        self._destination = None
        self._trade_target = None
        self._affiliate_address = None
        self._affiliate_basis_points = None
        self._signer = None
        self._aggregator = None
        self._aggregator_target_address = None
        self._aggregator_target_limit = None
        self._order_type = None
        self._stream_quantity = None
        self._stream_interval = None
        self.discriminator = None
        self.tx = tx
        self.target_asset = target_asset
        if destination is not None:
            self.destination = destination
        self.trade_target = trade_target
        if affiliate_address is not None:
            self.affiliate_address = affiliate_address
        self.affiliate_basis_points = affiliate_basis_points
        if signer is not None:
            self.signer = signer
        if aggregator is not None:
            self.aggregator = aggregator
        if aggregator_target_address is not None:
            self.aggregator_target_address = aggregator_target_address
        if aggregator_target_limit is not None:
            self.aggregator_target_limit = aggregator_target_limit
        if order_type is not None:
            self.order_type = order_type
        if stream_quantity is not None:
            self.stream_quantity = stream_quantity
        if stream_interval is not None:
            self.stream_interval = stream_interval

    @property
    def tx(self):
        """Gets the tx of this MsgSwap.  # noqa: E501


        :return: The tx of this MsgSwap.  # noqa: E501
        :rtype: Tx
        """
        return self._tx

    @tx.setter
    def tx(self, tx):
        """Sets the tx of this MsgSwap.


        :param tx: The tx of this MsgSwap.  # noqa: E501
        :type: Tx
        """
        if tx is None:
            raise ValueError("Invalid value for `tx`, must not be `None`")  # noqa: E501

        self._tx = tx

    @property
    def target_asset(self):
        """Gets the target_asset of this MsgSwap.  # noqa: E501

        the asset to be swapped to  # noqa: E501

        :return: The target_asset of this MsgSwap.  # noqa: E501
        :rtype: str
        """
        return self._target_asset

    @target_asset.setter
    def target_asset(self, target_asset):
        """Sets the target_asset of this MsgSwap.

        the asset to be swapped to  # noqa: E501

        :param target_asset: The target_asset of this MsgSwap.  # noqa: E501
        :type: str
        """
        if target_asset is None:
            raise ValueError("Invalid value for `target_asset`, must not be `None`")  # noqa: E501

        self._target_asset = target_asset

    @property
    def destination(self):
        """Gets the destination of this MsgSwap.  # noqa: E501

        the destination address to receive the swap output  # noqa: E501

        :return: The destination of this MsgSwap.  # noqa: E501
        :rtype: str
        """
        return self._destination

    @destination.setter
    def destination(self, destination):
        """Sets the destination of this MsgSwap.

        the destination address to receive the swap output  # noqa: E501

        :param destination: The destination of this MsgSwap.  # noqa: E501
        :type: str
        """

        self._destination = destination

    @property
    def trade_target(self):
        """Gets the trade_target of this MsgSwap.  # noqa: E501

        the minimum amount of output asset to receive (else cancelling and refunding the swap)  # noqa: E501

        :return: The trade_target of this MsgSwap.  # noqa: E501
        :rtype: str
        """
        return self._trade_target

    @trade_target.setter
    def trade_target(self, trade_target):
        """Sets the trade_target of this MsgSwap.

        the minimum amount of output asset to receive (else cancelling and refunding the swap)  # noqa: E501

        :param trade_target: The trade_target of this MsgSwap.  # noqa: E501
        :type: str
        """
        if trade_target is None:
            raise ValueError("Invalid value for `trade_target`, must not be `None`")  # noqa: E501

        self._trade_target = trade_target

    @property
    def affiliate_address(self):
        """Gets the affiliate_address of this MsgSwap.  # noqa: E501

        the affiliate address which will receive any affiliate fee  # noqa: E501

        :return: The affiliate_address of this MsgSwap.  # noqa: E501
        :rtype: str
        """
        return self._affiliate_address

    @affiliate_address.setter
    def affiliate_address(self, affiliate_address):
        """Sets the affiliate_address of this MsgSwap.

        the affiliate address which will receive any affiliate fee  # noqa: E501

        :param affiliate_address: The affiliate_address of this MsgSwap.  # noqa: E501
        :type: str
        """

        self._affiliate_address = affiliate_address

    @property
    def affiliate_basis_points(self):
        """Gets the affiliate_basis_points of this MsgSwap.  # noqa: E501

        the affiliate fee in basis points  # noqa: E501

        :return: The affiliate_basis_points of this MsgSwap.  # noqa: E501
        :rtype: str
        """
        return self._affiliate_basis_points

    @affiliate_basis_points.setter
    def affiliate_basis_points(self, affiliate_basis_points):
        """Sets the affiliate_basis_points of this MsgSwap.

        the affiliate fee in basis points  # noqa: E501

        :param affiliate_basis_points: The affiliate_basis_points of this MsgSwap.  # noqa: E501
        :type: str
        """
        if affiliate_basis_points is None:
            raise ValueError("Invalid value for `affiliate_basis_points`, must not be `None`")  # noqa: E501

        self._affiliate_basis_points = affiliate_basis_points

    @property
    def signer(self):
        """Gets the signer of this MsgSwap.  # noqa: E501

        the signer (sender) of the transaction  # noqa: E501

        :return: The signer of this MsgSwap.  # noqa: E501
        :rtype: str
        """
        return self._signer

    @signer.setter
    def signer(self, signer):
        """Sets the signer of this MsgSwap.

        the signer (sender) of the transaction  # noqa: E501

        :param signer: The signer of this MsgSwap.  # noqa: E501
        :type: str
        """

        self._signer = signer

    @property
    def aggregator(self):
        """Gets the aggregator of this MsgSwap.  # noqa: E501

        the contract address if an aggregator is specified for a non-THORChain SwapOut  # noqa: E501

        :return: The aggregator of this MsgSwap.  # noqa: E501
        :rtype: str
        """
        return self._aggregator

    @aggregator.setter
    def aggregator(self, aggregator):
        """Sets the aggregator of this MsgSwap.

        the contract address if an aggregator is specified for a non-THORChain SwapOut  # noqa: E501

        :param aggregator: The aggregator of this MsgSwap.  # noqa: E501
        :type: str
        """

        self._aggregator = aggregator

    @property
    def aggregator_target_address(self):
        """Gets the aggregator_target_address of this MsgSwap.  # noqa: E501

        the desired output asset of the aggregator SwapOut  # noqa: E501

        :return: The aggregator_target_address of this MsgSwap.  # noqa: E501
        :rtype: str
        """
        return self._aggregator_target_address

    @aggregator_target_address.setter
    def aggregator_target_address(self, aggregator_target_address):
        """Sets the aggregator_target_address of this MsgSwap.

        the desired output asset of the aggregator SwapOut  # noqa: E501

        :param aggregator_target_address: The aggregator_target_address of this MsgSwap.  # noqa: E501
        :type: str
        """

        self._aggregator_target_address = aggregator_target_address

    @property
    def aggregator_target_limit(self):
        """Gets the aggregator_target_limit of this MsgSwap.  # noqa: E501

        the minimum amount of SwapOut asset to receive (else cancelling the SwapOut and receiving THORChain's output)  # noqa: E501

        :return: The aggregator_target_limit of this MsgSwap.  # noqa: E501
        :rtype: str
        """
        return self._aggregator_target_limit

    @aggregator_target_limit.setter
    def aggregator_target_limit(self, aggregator_target_limit):
        """Sets the aggregator_target_limit of this MsgSwap.

        the minimum amount of SwapOut asset to receive (else cancelling the SwapOut and receiving THORChain's output)  # noqa: E501

        :param aggregator_target_limit: The aggregator_target_limit of this MsgSwap.  # noqa: E501
        :type: str
        """

        self._aggregator_target_limit = aggregator_target_limit

    @property
    def order_type(self):
        """Gets the order_type of this MsgSwap.  # noqa: E501

        market if immediately completed or refunded, limit if held until fulfillable  # noqa: E501

        :return: The order_type of this MsgSwap.  # noqa: E501
        :rtype: str
        """
        return self._order_type

    @order_type.setter
    def order_type(self, order_type):
        """Sets the order_type of this MsgSwap.

        market if immediately completed or refunded, limit if held until fulfillable  # noqa: E501

        :param order_type: The order_type of this MsgSwap.  # noqa: E501
        :type: str
        """

        self._order_type = order_type

    @property
    def stream_quantity(self):
        """Gets the stream_quantity of this MsgSwap.  # noqa: E501

        number of swaps to execute in a streaming swap  # noqa: E501

        :return: The stream_quantity of this MsgSwap.  # noqa: E501
        :rtype: int
        """
        return self._stream_quantity

    @stream_quantity.setter
    def stream_quantity(self, stream_quantity):
        """Sets the stream_quantity of this MsgSwap.

        number of swaps to execute in a streaming swap  # noqa: E501

        :param stream_quantity: The stream_quantity of this MsgSwap.  # noqa: E501
        :type: int
        """

        self._stream_quantity = stream_quantity

    @property
    def stream_interval(self):
        """Gets the stream_interval of this MsgSwap.  # noqa: E501

        the interval (in blocks) to execute the streaming swap  # noqa: E501

        :return: The stream_interval of this MsgSwap.  # noqa: E501
        :rtype: int
        """
        return self._stream_interval

    @stream_interval.setter
    def stream_interval(self, stream_interval):
        """Sets the stream_interval of this MsgSwap.

        the interval (in blocks) to execute the streaming swap  # noqa: E501

        :param stream_interval: The stream_interval of this MsgSwap.  # noqa: E501
        :type: int
        """

        self._stream_interval = stream_interval

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MsgSwap, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MsgSwap):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BlockResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'BlockResponseId',
        'header': 'BlockResponseHeader',
        'begin_block_events': 'list[dict(str, str)]',
        'end_block_events': 'list[dict(str, str)]',
        'txs': 'list[BlockTx]'
    }

    attribute_map = {
        'id': 'id',
        'header': 'header',
        'begin_block_events': 'begin_block_events',
        'end_block_events': 'end_block_events',
        'txs': 'txs'
    }

    def __init__(self, id=None, header=None, begin_block_events=None, end_block_events=None, txs=None):  # noqa: E501
        """BlockResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._header = None
        self._begin_block_events = None
        self._end_block_events = None
        self._txs = None
        self.discriminator = None
        self.id = id
        self.header = header
        self.begin_block_events = begin_block_events
        self.end_block_events = end_block_events
        self.txs = txs

    @property
    def id(self):
        """Gets the id of this BlockResponse.  # noqa: E501


        :return: The id of this BlockResponse.  # noqa: E501
        :rtype: BlockResponseId
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BlockResponse.


        :param id: The id of this BlockResponse.  # noqa: E501
        :type: BlockResponseId
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def header(self):
        """Gets the header of this BlockResponse.  # noqa: E501


        :return: The header of this BlockResponse.  # noqa: E501
        :rtype: BlockResponseHeader
        """
        return self._header

    @header.setter
    def header(self, header):
        """Sets the header of this BlockResponse.


        :param header: The header of this BlockResponse.  # noqa: E501
        :type: BlockResponseHeader
        """
        if header is None:
            raise ValueError("Invalid value for `header`, must not be `None`")  # noqa: E501

        self._header = header

    @property
    def begin_block_events(self):
        """Gets the begin_block_events of this BlockResponse.  # noqa: E501


        :return: The begin_block_events of this BlockResponse.  # noqa: E501
        :rtype: list[dict(str, str)]
        """
        return self._begin_block_events

    @begin_block_events.setter
    def begin_block_events(self, begin_block_events):
        """Sets the begin_block_events of this BlockResponse.


        :param begin_block_events: The begin_block_events of this BlockResponse.  # noqa: E501
        :type: list[dict(str, str)]
        """
        if begin_block_events is None:
            raise ValueError("Invalid value for `begin_block_events`, must not be `None`")  # noqa: E501

        self._begin_block_events = begin_block_events

    @property
    def end_block_events(self):
        """Gets the end_block_events of this BlockResponse.  # noqa: E501


        :return: The end_block_events of this BlockResponse.  # noqa: E501
        :rtype: list[dict(str, str)]
        """
        return self._end_block_events

    @end_block_events.setter
    def end_block_events(self, end_block_events):
        """Sets the end_block_events of this BlockResponse.


        :param end_block_events: The end_block_events of this BlockResponse.  # noqa: E501
        :type: list[dict(str, str)]
        """
        if end_block_events is None:
            raise ValueError("Invalid value for `end_block_events`, must not be `None`")  # noqa: E501

        self._end_block_events = end_block_events

    @property
    def txs(self):
        """Gets the txs of this BlockResponse.  # noqa: E501


        :return: The txs of this BlockResponse.  # noqa: E501
        :rtype: list[BlockTx]
        """
        return self._txs

    @txs.setter
    def txs(self, txs):
        """Sets the txs of this BlockResponse.


        :param txs: The txs of this BlockResponse.  # noqa: E501
        :type: list[BlockTx]
        """
        if txs is None:
            raise ValueError("Invalid value for `txs`, must not be `None`")  # noqa: E501

        self._txs = txs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BlockResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BlockResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class YggdrasilVault(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'block_height': 'int',
        'pub_key': 'str',
        'coins': 'list[Coin]',
        'type': 'str',
        'status_since': 'int',
        'membership': 'list[str]',
        'chains': 'list[str]',
        'inbound_tx_count': 'int',
        'outbound_tx_count': 'int',
        'pending_tx_block_heights': 'list[int]',
        'routers': 'list[VaultRouter]',
        'status': 'str',
        'bond': 'str',
        'total_value': 'str',
        'addresses': 'list[VaultAddress]'
    }

    attribute_map = {
        'block_height': 'block_height',
        'pub_key': 'pub_key',
        'coins': 'coins',
        'type': 'type',
        'status_since': 'status_since',
        'membership': 'membership',
        'chains': 'chains',
        'inbound_tx_count': 'inbound_tx_count',
        'outbound_tx_count': 'outbound_tx_count',
        'pending_tx_block_heights': 'pending_tx_block_heights',
        'routers': 'routers',
        'status': 'status',
        'bond': 'bond',
        'total_value': 'total_value',
        'addresses': 'addresses'
    }

    def __init__(self, block_height=None, pub_key=None, coins=None, type=None, status_since=None, membership=None, chains=None, inbound_tx_count=None, outbound_tx_count=None, pending_tx_block_heights=None, routers=None, status=None, bond=None, total_value=None, addresses=None):  # noqa: E501
        """YggdrasilVault - a model defined in Swagger"""  # noqa: E501
        self._block_height = None
        self._pub_key = None
        self._coins = None
        self._type = None
        self._status_since = None
        self._membership = None
        self._chains = None
        self._inbound_tx_count = None
        self._outbound_tx_count = None
        self._pending_tx_block_heights = None
        self._routers = None
        self._status = None
        self._bond = None
        self._total_value = None
        self._addresses = None
        self.discriminator = None
        if block_height is not None:
            self.block_height = block_height
        if pub_key is not None:
            self.pub_key = pub_key
        self.coins = coins
        if type is not None:
            self.type = type
        if status_since is not None:
            self.status_since = status_since
        if membership is not None:
            self.membership = membership
        if chains is not None:
            self.chains = chains
        if inbound_tx_count is not None:
            self.inbound_tx_count = inbound_tx_count
        if outbound_tx_count is not None:
            self.outbound_tx_count = outbound_tx_count
        if pending_tx_block_heights is not None:
            self.pending_tx_block_heights = pending_tx_block_heights
        self.routers = routers
        self.status = status
        self.bond = bond
        self.total_value = total_value
        self.addresses = addresses

    @property
    def block_height(self):
        """Gets the block_height of this YggdrasilVault.  # noqa: E501


        :return: The block_height of this YggdrasilVault.  # noqa: E501
        :rtype: int
        """
        return self._block_height

    @block_height.setter
    def block_height(self, block_height):
        """Sets the block_height of this YggdrasilVault.


        :param block_height: The block_height of this YggdrasilVault.  # noqa: E501
        :type: int
        """

        self._block_height = block_height

    @property
    def pub_key(self):
        """Gets the pub_key of this YggdrasilVault.  # noqa: E501


        :return: The pub_key of this YggdrasilVault.  # noqa: E501
        :rtype: str
        """
        return self._pub_key

    @pub_key.setter
    def pub_key(self, pub_key):
        """Sets the pub_key of this YggdrasilVault.


        :param pub_key: The pub_key of this YggdrasilVault.  # noqa: E501
        :type: str
        """

        self._pub_key = pub_key

    @property
    def coins(self):
        """Gets the coins of this YggdrasilVault.  # noqa: E501


        :return: The coins of this YggdrasilVault.  # noqa: E501
        :rtype: list[Coin]
        """
        return self._coins

    @coins.setter
    def coins(self, coins):
        """Sets the coins of this YggdrasilVault.


        :param coins: The coins of this YggdrasilVault.  # noqa: E501
        :type: list[Coin]
        """
        if coins is None:
            raise ValueError("Invalid value for `coins`, must not be `None`")  # noqa: E501

        self._coins = coins

    @property
    def type(self):
        """Gets the type of this YggdrasilVault.  # noqa: E501


        :return: The type of this YggdrasilVault.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this YggdrasilVault.


        :param type: The type of this YggdrasilVault.  # noqa: E501
        :type: str
        """
        allowed_values = ["AsgardVault", "YggdrasilVault"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def status_since(self):
        """Gets the status_since of this YggdrasilVault.  # noqa: E501


        :return: The status_since of this YggdrasilVault.  # noqa: E501
        :rtype: int
        """
        return self._status_since

    @status_since.setter
    def status_since(self, status_since):
        """Sets the status_since of this YggdrasilVault.


        :param status_since: The status_since of this YggdrasilVault.  # noqa: E501
        :type: int
        """

        self._status_since = status_since

    @property
    def membership(self):
        """Gets the membership of this YggdrasilVault.  # noqa: E501

        the list of node public keys which are members of the vault  # noqa: E501

        :return: The membership of this YggdrasilVault.  # noqa: E501
        :rtype: list[str]
        """
        return self._membership

    @membership.setter
    def membership(self, membership):
        """Sets the membership of this YggdrasilVault.

        the list of node public keys which are members of the vault  # noqa: E501

        :param membership: The membership of this YggdrasilVault.  # noqa: E501
        :type: list[str]
        """

        self._membership = membership

    @property
    def chains(self):
        """Gets the chains of this YggdrasilVault.  # noqa: E501


        :return: The chains of this YggdrasilVault.  # noqa: E501
        :rtype: list[str]
        """
        return self._chains

    @chains.setter
    def chains(self, chains):
        """Sets the chains of this YggdrasilVault.


        :param chains: The chains of this YggdrasilVault.  # noqa: E501
        :type: list[str]
        """

        self._chains = chains

    @property
    def inbound_tx_count(self):
        """Gets the inbound_tx_count of this YggdrasilVault.  # noqa: E501


        :return: The inbound_tx_count of this YggdrasilVault.  # noqa: E501
        :rtype: int
        """
        return self._inbound_tx_count

    @inbound_tx_count.setter
    def inbound_tx_count(self, inbound_tx_count):
        """Sets the inbound_tx_count of this YggdrasilVault.


        :param inbound_tx_count: The inbound_tx_count of this YggdrasilVault.  # noqa: E501
        :type: int
        """

        self._inbound_tx_count = inbound_tx_count

    @property
    def outbound_tx_count(self):
        """Gets the outbound_tx_count of this YggdrasilVault.  # noqa: E501


        :return: The outbound_tx_count of this YggdrasilVault.  # noqa: E501
        :rtype: int
        """
        return self._outbound_tx_count

    @outbound_tx_count.setter
    def outbound_tx_count(self, outbound_tx_count):
        """Sets the outbound_tx_count of this YggdrasilVault.


        :param outbound_tx_count: The outbound_tx_count of this YggdrasilVault.  # noqa: E501
        :type: int
        """

        self._outbound_tx_count = outbound_tx_count

    @property
    def pending_tx_block_heights(self):
        """Gets the pending_tx_block_heights of this YggdrasilVault.  # noqa: E501


        :return: The pending_tx_block_heights of this YggdrasilVault.  # noqa: E501
        :rtype: list[int]
        """
        return self._pending_tx_block_heights

    @pending_tx_block_heights.setter
    def pending_tx_block_heights(self, pending_tx_block_heights):
        """Sets the pending_tx_block_heights of this YggdrasilVault.


        :param pending_tx_block_heights: The pending_tx_block_heights of this YggdrasilVault.  # noqa: E501
        :type: list[int]
        """

        self._pending_tx_block_heights = pending_tx_block_heights

    @property
    def routers(self):
        """Gets the routers of this YggdrasilVault.  # noqa: E501


        :return: The routers of this YggdrasilVault.  # noqa: E501
        :rtype: list[VaultRouter]
        """
        return self._routers

    @routers.setter
    def routers(self, routers):
        """Sets the routers of this YggdrasilVault.


        :param routers: The routers of this YggdrasilVault.  # noqa: E501
        :type: list[VaultRouter]
        """
        if routers is None:
            raise ValueError("Invalid value for `routers`, must not be `None`")  # noqa: E501

        self._routers = routers

    @property
    def status(self):
        """Gets the status of this YggdrasilVault.  # noqa: E501


        :return: The status of this YggdrasilVault.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this YggdrasilVault.


        :param status: The status of this YggdrasilVault.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def bond(self):
        """Gets the bond of this YggdrasilVault.  # noqa: E501

        current node bond  # noqa: E501

        :return: The bond of this YggdrasilVault.  # noqa: E501
        :rtype: str
        """
        return self._bond

    @bond.setter
    def bond(self, bond):
        """Sets the bond of this YggdrasilVault.

        current node bond  # noqa: E501

        :param bond: The bond of this YggdrasilVault.  # noqa: E501
        :type: str
        """
        if bond is None:
            raise ValueError("Invalid value for `bond`, must not be `None`")  # noqa: E501

        self._bond = bond

    @property
    def total_value(self):
        """Gets the total_value of this YggdrasilVault.  # noqa: E501

        value in rune of the vault's assets  # noqa: E501

        :return: The total_value of this YggdrasilVault.  # noqa: E501
        :rtype: str
        """
        return self._total_value

    @total_value.setter
    def total_value(self, total_value):
        """Sets the total_value of this YggdrasilVault.

        value in rune of the vault's assets  # noqa: E501

        :param total_value: The total_value of this YggdrasilVault.  # noqa: E501
        :type: str
        """
        if total_value is None:
            raise ValueError("Invalid value for `total_value`, must not be `None`")  # noqa: E501

        self._total_value = total_value

    @property
    def addresses(self):
        """Gets the addresses of this YggdrasilVault.  # noqa: E501


        :return: The addresses of this YggdrasilVault.  # noqa: E501
        :rtype: list[VaultAddress]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """Sets the addresses of this YggdrasilVault.


        :param addresses: The addresses of this YggdrasilVault.  # noqa: E501
        :type: list[VaultAddress]
        """
        if addresses is None:
            raise ValueError("Invalid value for `addresses`, must not be `None`")  # noqa: E501

        self._addresses = addresses

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(YggdrasilVault, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, YggdrasilVault):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RUNEProvider(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'rune_address': 'str',
        'units': 'str',
        'value': 'str',
        'pnl': 'str',
        'deposit_amount': 'str',
        'withdraw_amount': 'str',
        'last_deposit_height': 'int',
        'last_withdraw_height': 'int'
    }

    attribute_map = {
        'rune_address': 'rune_address',
        'units': 'units',
        'value': 'value',
        'pnl': 'pnl',
        'deposit_amount': 'deposit_amount',
        'withdraw_amount': 'withdraw_amount',
        'last_deposit_height': 'last_deposit_height',
        'last_withdraw_height': 'last_withdraw_height'
    }

    def __init__(self, rune_address=None, units=None, value=None, pnl=None, deposit_amount=None, withdraw_amount=None, last_deposit_height=None, last_withdraw_height=None):  # noqa: E501
        """RUNEProvider - a model defined in Swagger"""  # noqa: E501
        self._rune_address = None
        self._units = None
        self._value = None
        self._pnl = None
        self._deposit_amount = None
        self._withdraw_amount = None
        self._last_deposit_height = None
        self._last_withdraw_height = None
        self.discriminator = None
        self.rune_address = rune_address
        self.units = units
        self.value = value
        self.pnl = pnl
        self.deposit_amount = deposit_amount
        self.withdraw_amount = withdraw_amount
        self.last_deposit_height = last_deposit_height
        self.last_withdraw_height = last_withdraw_height

    @property
    def rune_address(self):
        """Gets the rune_address of this RUNEProvider.  # noqa: E501


        :return: The rune_address of this RUNEProvider.  # noqa: E501
        :rtype: str
        """
        return self._rune_address

    @rune_address.setter
    def rune_address(self, rune_address):
        """Sets the rune_address of this RUNEProvider.


        :param rune_address: The rune_address of this RUNEProvider.  # noqa: E501
        :type: str
        """
        if rune_address is None:
            raise ValueError("Invalid value for `rune_address`, must not be `None`")  # noqa: E501

        self._rune_address = rune_address

    @property
    def units(self):
        """Gets the units of this RUNEProvider.  # noqa: E501


        :return: The units of this RUNEProvider.  # noqa: E501
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this RUNEProvider.


        :param units: The units of this RUNEProvider.  # noqa: E501
        :type: str
        """
        if units is None:
            raise ValueError("Invalid value for `units`, must not be `None`")  # noqa: E501

        self._units = units

    @property
    def value(self):
        """Gets the value of this RUNEProvider.  # noqa: E501


        :return: The value of this RUNEProvider.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this RUNEProvider.


        :param value: The value of this RUNEProvider.  # noqa: E501
        :type: str
        """
        if value is None:
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def pnl(self):
        """Gets the pnl of this RUNEProvider.  # noqa: E501


        :return: The pnl of this RUNEProvider.  # noqa: E501
        :rtype: str
        """
        return self._pnl

    @pnl.setter
    def pnl(self, pnl):
        """Sets the pnl of this RUNEProvider.


        :param pnl: The pnl of this RUNEProvider.  # noqa: E501
        :type: str
        """
        if pnl is None:
            raise ValueError("Invalid value for `pnl`, must not be `None`")  # noqa: E501

        self._pnl = pnl

    @property
    def deposit_amount(self):
        """Gets the deposit_amount of this RUNEProvider.  # noqa: E501


        :return: The deposit_amount of this RUNEProvider.  # noqa: E501
        :rtype: str
        """
        return self._deposit_amount

    @deposit_amount.setter
    def deposit_amount(self, deposit_amount):
        """Sets the deposit_amount of this RUNEProvider.


        :param deposit_amount: The deposit_amount of this RUNEProvider.  # noqa: E501
        :type: str
        """
        if deposit_amount is None:
            raise ValueError("Invalid value for `deposit_amount`, must not be `None`")  # noqa: E501

        self._deposit_amount = deposit_amount

    @property
    def withdraw_amount(self):
        """Gets the withdraw_amount of this RUNEProvider.  # noqa: E501


        :return: The withdraw_amount of this RUNEProvider.  # noqa: E501
        :rtype: str
        """
        return self._withdraw_amount

    @withdraw_amount.setter
    def withdraw_amount(self, withdraw_amount):
        """Sets the withdraw_amount of this RUNEProvider.


        :param withdraw_amount: The withdraw_amount of this RUNEProvider.  # noqa: E501
        :type: str
        """
        if withdraw_amount is None:
            raise ValueError("Invalid value for `withdraw_amount`, must not be `None`")  # noqa: E501

        self._withdraw_amount = withdraw_amount

    @property
    def last_deposit_height(self):
        """Gets the last_deposit_height of this RUNEProvider.  # noqa: E501


        :return: The last_deposit_height of this RUNEProvider.  # noqa: E501
        :rtype: int
        """
        return self._last_deposit_height

    @last_deposit_height.setter
    def last_deposit_height(self, last_deposit_height):
        """Sets the last_deposit_height of this RUNEProvider.


        :param last_deposit_height: The last_deposit_height of this RUNEProvider.  # noqa: E501
        :type: int
        """
        if last_deposit_height is None:
            raise ValueError("Invalid value for `last_deposit_height`, must not be `None`")  # noqa: E501

        self._last_deposit_height = last_deposit_height

    @property
    def last_withdraw_height(self):
        """Gets the last_withdraw_height of this RUNEProvider.  # noqa: E501


        :return: The last_withdraw_height of this RUNEProvider.  # noqa: E501
        :rtype: int
        """
        return self._last_withdraw_height

    @last_withdraw_height.setter
    def last_withdraw_height(self, last_withdraw_height):
        """Sets the last_withdraw_height of this RUNEProvider.


        :param last_withdraw_height: The last_withdraw_height of this RUNEProvider.  # noqa: E501
        :type: int
        """
        if last_withdraw_height is None:
            raise ValueError("Invalid value for `last_withdraw_height`, must not be `None`")  # noqa: E501

        self._last_withdraw_height = last_withdraw_height

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RUNEProvider, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RUNEProvider):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TxStatusResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'tx': 'Tx',
        'planned_out_txs': 'list[PlannedOutTx]',
        'out_txs': 'list[Tx]',
        'stages': 'TxStagesResponse'
    }

    attribute_map = {
        'tx': 'tx',
        'planned_out_txs': 'planned_out_txs',
        'out_txs': 'out_txs',
        'stages': 'stages'
    }

    def __init__(self, tx=None, planned_out_txs=None, out_txs=None, stages=None):  # noqa: E501
        """TxStatusResponse - a model defined in Swagger"""  # noqa: E501
        self._tx = None
        self._planned_out_txs = None
        self._out_txs = None
        self._stages = None
        self.discriminator = None
        if tx is not None:
            self.tx = tx
        if planned_out_txs is not None:
            self.planned_out_txs = planned_out_txs
        if out_txs is not None:
            self.out_txs = out_txs
        self.stages = stages

    @property
    def tx(self):
        """Gets the tx of this TxStatusResponse.  # noqa: E501


        :return: The tx of this TxStatusResponse.  # noqa: E501
        :rtype: Tx
        """
        return self._tx

    @tx.setter
    def tx(self, tx):
        """Sets the tx of this TxStatusResponse.


        :param tx: The tx of this TxStatusResponse.  # noqa: E501
        :type: Tx
        """

        self._tx = tx

    @property
    def planned_out_txs(self):
        """Gets the planned_out_txs of this TxStatusResponse.  # noqa: E501


        :return: The planned_out_txs of this TxStatusResponse.  # noqa: E501
        :rtype: list[PlannedOutTx]
        """
        return self._planned_out_txs

    @planned_out_txs.setter
    def planned_out_txs(self, planned_out_txs):
        """Sets the planned_out_txs of this TxStatusResponse.


        :param planned_out_txs: The planned_out_txs of this TxStatusResponse.  # noqa: E501
        :type: list[PlannedOutTx]
        """

        self._planned_out_txs = planned_out_txs

    @property
    def out_txs(self):
        """Gets the out_txs of this TxStatusResponse.  # noqa: E501


        :return: The out_txs of this TxStatusResponse.  # noqa: E501
        :rtype: list[Tx]
        """
        return self._out_txs

    @out_txs.setter
    def out_txs(self, out_txs):
        """Sets the out_txs of this TxStatusResponse.


        :param out_txs: The out_txs of this TxStatusResponse.  # noqa: E501
        :type: list[Tx]
        """

        self._out_txs = out_txs

    @property
    def stages(self):
        """Gets the stages of this TxStatusResponse.  # noqa: E501


        :return: The stages of this TxStatusResponse.  # noqa: E501
        :rtype: TxStagesResponse
        """
        return self._stages

    @stages.setter
    def stages(self, stages):
        """Sets the stages of this TxStatusResponse.


        :param stages: The stages of this TxStatusResponse.  # noqa: E501
        :type: TxStagesResponse
        """
        if stages is None:
            raise ValueError("Invalid value for `stages`, must not be `None`")  # noqa: E501

        self._stages = stages

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TxStatusResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TxStatusResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BlockResponseHeader(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'version': 'BlockResponseHeaderVersion',
        'chain_id': 'str',
        'height': 'int',
        'time': 'str',
        'last_block_id': 'BlockResponseId',
        'last_commit_hash': 'str',
        'data_hash': 'str',
        'validators_hash': 'str',
        'next_validators_hash': 'str',
        'consensus_hash': 'str',
        'app_hash': 'str',
        'last_results_hash': 'str',
        'evidence_hash': 'str',
        'proposer_address': 'str'
    }

    attribute_map = {
        'version': 'version',
        'chain_id': 'chain_id',
        'height': 'height',
        'time': 'time',
        'last_block_id': 'last_block_id',
        'last_commit_hash': 'last_commit_hash',
        'data_hash': 'data_hash',
        'validators_hash': 'validators_hash',
        'next_validators_hash': 'next_validators_hash',
        'consensus_hash': 'consensus_hash',
        'app_hash': 'app_hash',
        'last_results_hash': 'last_results_hash',
        'evidence_hash': 'evidence_hash',
        'proposer_address': 'proposer_address'
    }

    def __init__(self, version=None, chain_id=None, height=None, time=None, last_block_id=None, last_commit_hash=None, data_hash=None, validators_hash=None, next_validators_hash=None, consensus_hash=None, app_hash=None, last_results_hash=None, evidence_hash=None, proposer_address=None):  # noqa: E501
        """BlockResponseHeader - a model defined in Swagger"""  # noqa: E501
        self._version = None
        self._chain_id = None
        self._height = None
        self._time = None
        self._last_block_id = None
        self._last_commit_hash = None
        self._data_hash = None
        self._validators_hash = None
        self._next_validators_hash = None
        self._consensus_hash = None
        self._app_hash = None
        self._last_results_hash = None
        self._evidence_hash = None
        self._proposer_address = None
        self.discriminator = None
        self.version = version
        self.chain_id = chain_id
        self.height = height
        self.time = time
        self.last_block_id = last_block_id
        self.last_commit_hash = last_commit_hash
        self.data_hash = data_hash
        self.validators_hash = validators_hash
        self.next_validators_hash = next_validators_hash
        self.consensus_hash = consensus_hash
        self.app_hash = app_hash
        self.last_results_hash = last_results_hash
        self.evidence_hash = evidence_hash
        self.proposer_address = proposer_address

    @property
    def version(self):
        """Gets the version of this BlockResponseHeader.  # noqa: E501


        :return: The version of this BlockResponseHeader.  # noqa: E501
        :rtype: BlockResponseHeaderVersion
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this BlockResponseHeader.


        :param version: The version of this BlockResponseHeader.  # noqa: E501
        :type: BlockResponseHeaderVersion
        """
        if version is None:
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501

        self._version = version

    @property
    def chain_id(self):
        """Gets the chain_id of this BlockResponseHeader.  # noqa: E501


        :return: The chain_id of this BlockResponseHeader.  # noqa: E501
        :rtype: str
        """
        return self._chain_id

    @chain_id.setter
    def chain_id(self, chain_id):
        """Sets the chain_id of this BlockResponseHeader.


        :param chain_id: The chain_id of this BlockResponseHeader.  # noqa: E501
        :type: str
        """
        if chain_id is None:
            raise ValueError("Invalid value for `chain_id`, must not be `None`")  # noqa: E501

        self._chain_id = chain_id

    @property
    def height(self):
        """Gets the height of this BlockResponseHeader.  # noqa: E501


        :return: The height of this BlockResponseHeader.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this BlockResponseHeader.


        :param height: The height of this BlockResponseHeader.  # noqa: E501
        :type: int
        """
        if height is None:
            raise ValueError("Invalid value for `height`, must not be `None`")  # noqa: E501

        self._height = height

    @property
    def time(self):
        """Gets the time of this BlockResponseHeader.  # noqa: E501


        :return: The time of this BlockResponseHeader.  # noqa: E501
        :rtype: str
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this BlockResponseHeader.


        :param time: The time of this BlockResponseHeader.  # noqa: E501
        :type: str
        """
        if time is None:
            raise ValueError("Invalid value for `time`, must not be `None`")  # noqa: E501

        self._time = time

    @property
    def last_block_id(self):
        """Gets the last_block_id of this BlockResponseHeader.  # noqa: E501


        :return: The last_block_id of this BlockResponseHeader.  # noqa: E501
        :rtype: BlockResponseId
        """
        return self._last_block_id

    @last_block_id.setter
    def last_block_id(self, last_block_id):
        """Sets the last_block_id of this BlockResponseHeader.


        :param last_block_id: The last_block_id of this BlockResponseHeader.  # noqa: E501
        :type: BlockResponseId
        """
        if last_block_id is None:
            raise ValueError("Invalid value for `last_block_id`, must not be `None`")  # noqa: E501

        self._last_block_id = last_block_id

    @property
    def last_commit_hash(self):
        """Gets the last_commit_hash of this BlockResponseHeader.  # noqa: E501


        :return: The last_commit_hash of this BlockResponseHeader.  # noqa: E501
        :rtype: str
        """
        return self._last_commit_hash

    @last_commit_hash.setter
    def last_commit_hash(self, last_commit_hash):
        """Sets the last_commit_hash of this BlockResponseHeader.


        :param last_commit_hash: The last_commit_hash of this BlockResponseHeader.  # noqa: E501
        :type: str
        """
        if last_commit_hash is None:
            raise ValueError("Invalid value for `last_commit_hash`, must not be `None`")  # noqa: E501

        self._last_commit_hash = last_commit_hash

    @property
    def data_hash(self):
        """Gets the data_hash of this BlockResponseHeader.  # noqa: E501


        :return: The data_hash of this BlockResponseHeader.  # noqa: E501
        :rtype: str
        """
        return self._data_hash

    @data_hash.setter
    def data_hash(self, data_hash):
        """Sets the data_hash of this BlockResponseHeader.


        :param data_hash: The data_hash of this BlockResponseHeader.  # noqa: E501
        :type: str
        """
        if data_hash is None:
            raise ValueError("Invalid value for `data_hash`, must not be `None`")  # noqa: E501

        self._data_hash = data_hash

    @property
    def validators_hash(self):
        """Gets the validators_hash of this BlockResponseHeader.  # noqa: E501


        :return: The validators_hash of this BlockResponseHeader.  # noqa: E501
        :rtype: str
        """
        return self._validators_hash

    @validators_hash.setter
    def validators_hash(self, validators_hash):
        """Sets the validators_hash of this BlockResponseHeader.


        :param validators_hash: The validators_hash of this BlockResponseHeader.  # noqa: E501
        :type: str
        """
        if validators_hash is None:
            raise ValueError("Invalid value for `validators_hash`, must not be `None`")  # noqa: E501

        self._validators_hash = validators_hash

    @property
    def next_validators_hash(self):
        """Gets the next_validators_hash of this BlockResponseHeader.  # noqa: E501


        :return: The next_validators_hash of this BlockResponseHeader.  # noqa: E501
        :rtype: str
        """
        return self._next_validators_hash

    @next_validators_hash.setter
    def next_validators_hash(self, next_validators_hash):
        """Sets the next_validators_hash of this BlockResponseHeader.


        :param next_validators_hash: The next_validators_hash of this BlockResponseHeader.  # noqa: E501
        :type: str
        """
        if next_validators_hash is None:
            raise ValueError("Invalid value for `next_validators_hash`, must not be `None`")  # noqa: E501

        self._next_validators_hash = next_validators_hash

    @property
    def consensus_hash(self):
        """Gets the consensus_hash of this BlockResponseHeader.  # noqa: E501


        :return: The consensus_hash of this BlockResponseHeader.  # noqa: E501
        :rtype: str
        """
        return self._consensus_hash

    @consensus_hash.setter
    def consensus_hash(self, consensus_hash):
        """Sets the consensus_hash of this BlockResponseHeader.


        :param consensus_hash: The consensus_hash of this BlockResponseHeader.  # noqa: E501
        :type: str
        """
        if consensus_hash is None:
            raise ValueError("Invalid value for `consensus_hash`, must not be `None`")  # noqa: E501

        self._consensus_hash = consensus_hash

    @property
    def app_hash(self):
        """Gets the app_hash of this BlockResponseHeader.  # noqa: E501


        :return: The app_hash of this BlockResponseHeader.  # noqa: E501
        :rtype: str
        """
        return self._app_hash

    @app_hash.setter
    def app_hash(self, app_hash):
        """Sets the app_hash of this BlockResponseHeader.


        :param app_hash: The app_hash of this BlockResponseHeader.  # noqa: E501
        :type: str
        """
        if app_hash is None:
            raise ValueError("Invalid value for `app_hash`, must not be `None`")  # noqa: E501

        self._app_hash = app_hash

    @property
    def last_results_hash(self):
        """Gets the last_results_hash of this BlockResponseHeader.  # noqa: E501


        :return: The last_results_hash of this BlockResponseHeader.  # noqa: E501
        :rtype: str
        """
        return self._last_results_hash

    @last_results_hash.setter
    def last_results_hash(self, last_results_hash):
        """Sets the last_results_hash of this BlockResponseHeader.


        :param last_results_hash: The last_results_hash of this BlockResponseHeader.  # noqa: E501
        :type: str
        """
        if last_results_hash is None:
            raise ValueError("Invalid value for `last_results_hash`, must not be `None`")  # noqa: E501

        self._last_results_hash = last_results_hash

    @property
    def evidence_hash(self):
        """Gets the evidence_hash of this BlockResponseHeader.  # noqa: E501


        :return: The evidence_hash of this BlockResponseHeader.  # noqa: E501
        :rtype: str
        """
        return self._evidence_hash

    @evidence_hash.setter
    def evidence_hash(self, evidence_hash):
        """Sets the evidence_hash of this BlockResponseHeader.


        :param evidence_hash: The evidence_hash of this BlockResponseHeader.  # noqa: E501
        :type: str
        """
        if evidence_hash is None:
            raise ValueError("Invalid value for `evidence_hash`, must not be `None`")  # noqa: E501

        self._evidence_hash = evidence_hash

    @property
    def proposer_address(self):
        """Gets the proposer_address of this BlockResponseHeader.  # noqa: E501


        :return: The proposer_address of this BlockResponseHeader.  # noqa: E501
        :rtype: str
        """
        return self._proposer_address

    @proposer_address.setter
    def proposer_address(self, proposer_address):
        """Sets the proposer_address of this BlockResponseHeader.


        :param proposer_address: The proposer_address of this BlockResponseHeader.  # noqa: E501
        :type: str
        """
        if proposer_address is None:
            raise ValueError("Invalid value for `proposer_address`, must not be `None`")  # noqa: E501

        self._proposer_address = proposer_address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BlockResponseHeader, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BlockResponseHeader):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InlineResponse200(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset': 'str',
        'pool_slip': 'int',
        'rollup_count': 'int',
        'long_rollup': 'int',
        'rollup': 'int',
        'summed_rollup': 'int'
    }

    attribute_map = {
        'asset': 'asset',
        'pool_slip': 'pool_slip',
        'rollup_count': 'rollup_count',
        'long_rollup': 'long_rollup',
        'rollup': 'rollup',
        'summed_rollup': 'summed_rollup'
    }

    def __init__(self, asset=None, pool_slip=None, rollup_count=None, long_rollup=None, rollup=None, summed_rollup=None):  # noqa: E501
        """InlineResponse200 - a model defined in Swagger"""  # noqa: E501
        self._asset = None
        self._pool_slip = None
        self._rollup_count = None
        self._long_rollup = None
        self._rollup = None
        self._summed_rollup = None
        self.discriminator = None
        self.asset = asset
        self.pool_slip = pool_slip
        self.rollup_count = rollup_count
        self.long_rollup = long_rollup
        self.rollup = rollup
        if summed_rollup is not None:
            self.summed_rollup = summed_rollup

    @property
    def asset(self):
        """Gets the asset of this InlineResponse200.  # noqa: E501


        :return: The asset of this InlineResponse200.  # noqa: E501
        :rtype: str
        """
        return self._asset

    @asset.setter
    def asset(self, asset):
        """Sets the asset of this InlineResponse200.


        :param asset: The asset of this InlineResponse200.  # noqa: E501
        :type: str
        """
        if asset is None:
            raise ValueError("Invalid value for `asset`, must not be `None`")  # noqa: E501

        self._asset = asset

    @property
    def pool_slip(self):
        """Gets the pool_slip of this InlineResponse200.  # noqa: E501

        Pool slip for this asset's pool for the current height  # noqa: E501

        :return: The pool_slip of this InlineResponse200.  # noqa: E501
        :rtype: int
        """
        return self._pool_slip

    @pool_slip.setter
    def pool_slip(self, pool_slip):
        """Sets the pool_slip of this InlineResponse200.

        Pool slip for this asset's pool for the current height  # noqa: E501

        :param pool_slip: The pool_slip of this InlineResponse200.  # noqa: E501
        :type: int
        """
        if pool_slip is None:
            raise ValueError("Invalid value for `pool_slip`, must not be `None`")  # noqa: E501

        self._pool_slip = pool_slip

    @property
    def rollup_count(self):
        """Gets the rollup_count of this InlineResponse200.  # noqa: E501

        Number of stored pool slips contributing to the current stored rollup  # noqa: E501

        :return: The rollup_count of this InlineResponse200.  # noqa: E501
        :rtype: int
        """
        return self._rollup_count

    @rollup_count.setter
    def rollup_count(self, rollup_count):
        """Sets the rollup_count of this InlineResponse200.

        Number of stored pool slips contributing to the current stored rollup  # noqa: E501

        :param rollup_count: The rollup_count of this InlineResponse200.  # noqa: E501
        :type: int
        """
        if rollup_count is None:
            raise ValueError("Invalid value for `rollup_count`, must not be `None`")  # noqa: E501

        self._rollup_count = rollup_count

    @property
    def long_rollup(self):
        """Gets the long_rollup of this InlineResponse200.  # noqa: E501

        Median of rollup snapshots over a long period  # noqa: E501

        :return: The long_rollup of this InlineResponse200.  # noqa: E501
        :rtype: int
        """
        return self._long_rollup

    @long_rollup.setter
    def long_rollup(self, long_rollup):
        """Sets the long_rollup of this InlineResponse200.

        Median of rollup snapshots over a long period  # noqa: E501

        :param long_rollup: The long_rollup of this InlineResponse200.  # noqa: E501
        :type: int
        """
        if long_rollup is None:
            raise ValueError("Invalid value for `long_rollup`, must not be `None`")  # noqa: E501

        self._long_rollup = long_rollup

    @property
    def rollup(self):
        """Gets the rollup of this InlineResponse200.  # noqa: E501

        Stored sum of pool slips over a number of previous block heights  # noqa: E501

        :return: The rollup of this InlineResponse200.  # noqa: E501
        :rtype: int
        """
        return self._rollup

    @rollup.setter
    def rollup(self, rollup):
        """Sets the rollup of this InlineResponse200.

        Stored sum of pool slips over a number of previous block heights  # noqa: E501

        :param rollup: The rollup of this InlineResponse200.  # noqa: E501
        :type: int
        """
        if rollup is None:
            raise ValueError("Invalid value for `rollup`, must not be `None`")  # noqa: E501

        self._rollup = rollup

    @property
    def summed_rollup(self):
        """Gets the summed_rollup of this InlineResponse200.  # noqa: E501

        Summed pool slips over a number of previous block heights, to checksum the stored rollup  # noqa: E501

        :return: The summed_rollup of this InlineResponse200.  # noqa: E501
        :rtype: int
        """
        return self._summed_rollup

    @summed_rollup.setter
    def summed_rollup(self, summed_rollup):
        """Sets the summed_rollup of this InlineResponse200.

        Summed pool slips over a number of previous block heights, to checksum the stored rollup  # noqa: E501

        :param summed_rollup: The summed_rollup of this InlineResponse200.  # noqa: E501
        :type: int
        """

        self._summed_rollup = summed_rollup

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BlockTxResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'code': 'int',
        'data': 'str',
        'log': 'str',
        'info': 'str',
        'gas_wanted': 'str',
        'gas_used': 'str',
        'events': 'list[dict(str, str)]',
        'codespace': 'str'
    }

    attribute_map = {
        'code': 'code',
        'data': 'data',
        'log': 'log',
        'info': 'info',
        'gas_wanted': 'gas_wanted',
        'gas_used': 'gas_used',
        'events': 'events',
        'codespace': 'codespace'
    }

    def __init__(self, code=None, data=None, log=None, info=None, gas_wanted=None, gas_used=None, events=None, codespace=None):  # noqa: E501
        """BlockTxResult - a model defined in Swagger"""  # noqa: E501
        self._code = None
        self._data = None
        self._log = None
        self._info = None
        self._gas_wanted = None
        self._gas_used = None
        self._events = None
        self._codespace = None
        self.discriminator = None
        if code is not None:
            self.code = code
        if data is not None:
            self.data = data
        if log is not None:
            self.log = log
        if info is not None:
            self.info = info
        if gas_wanted is not None:
            self.gas_wanted = gas_wanted
        if gas_used is not None:
            self.gas_used = gas_used
        if events is not None:
            self.events = events
        if codespace is not None:
            self.codespace = codespace

    @property
    def code(self):
        """Gets the code of this BlockTxResult.  # noqa: E501


        :return: The code of this BlockTxResult.  # noqa: E501
        :rtype: int
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this BlockTxResult.


        :param code: The code of this BlockTxResult.  # noqa: E501
        :type: int
        """

        self._code = code

    @property
    def data(self):
        """Gets the data of this BlockTxResult.  # noqa: E501


        :return: The data of this BlockTxResult.  # noqa: E501
        :rtype: str
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this BlockTxResult.


        :param data: The data of this BlockTxResult.  # noqa: E501
        :type: str
        """

        self._data = data

    @property
    def log(self):
        """Gets the log of this BlockTxResult.  # noqa: E501


        :return: The log of this BlockTxResult.  # noqa: E501
        :rtype: str
        """
        return self._log

    @log.setter
    def log(self, log):
        """Sets the log of this BlockTxResult.


        :param log: The log of this BlockTxResult.  # noqa: E501
        :type: str
        """

        self._log = log

    @property
    def info(self):
        """Gets the info of this BlockTxResult.  # noqa: E501


        :return: The info of this BlockTxResult.  # noqa: E501
        :rtype: str
        """
        return self._info

    @info.setter
    def info(self, info):
        """Sets the info of this BlockTxResult.


        :param info: The info of this BlockTxResult.  # noqa: E501
        :type: str
        """

        self._info = info

    @property
    def gas_wanted(self):
        """Gets the gas_wanted of this BlockTxResult.  # noqa: E501


        :return: The gas_wanted of this BlockTxResult.  # noqa: E501
        :rtype: str
        """
        return self._gas_wanted

    @gas_wanted.setter
    def gas_wanted(self, gas_wanted):
        """Sets the gas_wanted of this BlockTxResult.


        :param gas_wanted: The gas_wanted of this BlockTxResult.  # noqa: E501
        :type: str
        """

        self._gas_wanted = gas_wanted

    @property
    def gas_used(self):
        """Gets the gas_used of this BlockTxResult.  # noqa: E501


        :return: The gas_used of this BlockTxResult.  # noqa: E501
        :rtype: str
        """
        return self._gas_used

    @gas_used.setter
    def gas_used(self, gas_used):
        """Sets the gas_used of this BlockTxResult.


        :param gas_used: The gas_used of this BlockTxResult.  # noqa: E501
        :type: str
        """

        self._gas_used = gas_used

    @property
    def events(self):
        """Gets the events of this BlockTxResult.  # noqa: E501


        :return: The events of this BlockTxResult.  # noqa: E501
        :rtype: list[dict(str, str)]
        """
        return self._events

    @events.setter
    def events(self, events):
        """Sets the events of this BlockTxResult.


        :param events: The events of this BlockTxResult.  # noqa: E501
        :type: list[dict(str, str)]
        """

        self._events = events

    @property
    def codespace(self):
        """Gets the codespace of this BlockTxResult.  # noqa: E501


        :return: The codespace of this BlockTxResult.  # noqa: E501
        :rtype: str
        """
        return self._codespace

    @codespace.setter
    def codespace(self, codespace):
        """Sets the codespace of this BlockTxResult.


        :param codespace: The codespace of this BlockTxResult.  # noqa: E501
        :type: str
        """

        self._codespace = codespace

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BlockTxResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BlockTxResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TxDetailsResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'tx_id': 'str',
        'tx': 'ObservedTx',
        'txs': 'list[ObservedTx]',
        'actions': 'list[TxOutItem]',
        'out_txs': 'list[Tx]',
        'consensus_height': 'int',
        'finalised_height': 'int',
        'updated_vault': 'bool',
        'reverted': 'bool',
        'outbound_height': 'int'
    }

    attribute_map = {
        'tx_id': 'tx_id',
        'tx': 'tx',
        'txs': 'txs',
        'actions': 'actions',
        'out_txs': 'out_txs',
        'consensus_height': 'consensus_height',
        'finalised_height': 'finalised_height',
        'updated_vault': 'updated_vault',
        'reverted': 'reverted',
        'outbound_height': 'outbound_height'
    }

    def __init__(self, tx_id=None, tx=None, txs=None, actions=None, out_txs=None, consensus_height=None, finalised_height=None, updated_vault=None, reverted=None, outbound_height=None):  # noqa: E501
        """TxDetailsResponse - a model defined in Swagger"""  # noqa: E501
        self._tx_id = None
        self._tx = None
        self._txs = None
        self._actions = None
        self._out_txs = None
        self._consensus_height = None
        self._finalised_height = None
        self._updated_vault = None
        self._reverted = None
        self._outbound_height = None
        self.discriminator = None
        if tx_id is not None:
            self.tx_id = tx_id
        if tx is not None:
            self.tx = tx
        if txs is not None:
            self.txs = txs
        if actions is not None:
            self.actions = actions
        if out_txs is not None:
            self.out_txs = out_txs
        if consensus_height is not None:
            self.consensus_height = consensus_height
        if finalised_height is not None:
            self.finalised_height = finalised_height
        if updated_vault is not None:
            self.updated_vault = updated_vault
        if reverted is not None:
            self.reverted = reverted
        if outbound_height is not None:
            self.outbound_height = outbound_height

    @property
    def tx_id(self):
        """Gets the tx_id of this TxDetailsResponse.  # noqa: E501


        :return: The tx_id of this TxDetailsResponse.  # noqa: E501
        :rtype: str
        """
        return self._tx_id

    @tx_id.setter
    def tx_id(self, tx_id):
        """Sets the tx_id of this TxDetailsResponse.


        :param tx_id: The tx_id of this TxDetailsResponse.  # noqa: E501
        :type: str
        """

        self._tx_id = tx_id

    @property
    def tx(self):
        """Gets the tx of this TxDetailsResponse.  # noqa: E501


        :return: The tx of this TxDetailsResponse.  # noqa: E501
        :rtype: ObservedTx
        """
        return self._tx

    @tx.setter
    def tx(self, tx):
        """Sets the tx of this TxDetailsResponse.


        :param tx: The tx of this TxDetailsResponse.  # noqa: E501
        :type: ObservedTx
        """

        self._tx = tx

    @property
    def txs(self):
        """Gets the txs of this TxDetailsResponse.  # noqa: E501


        :return: The txs of this TxDetailsResponse.  # noqa: E501
        :rtype: list[ObservedTx]
        """
        return self._txs

    @txs.setter
    def txs(self, txs):
        """Sets the txs of this TxDetailsResponse.


        :param txs: The txs of this TxDetailsResponse.  # noqa: E501
        :type: list[ObservedTx]
        """

        self._txs = txs

    @property
    def actions(self):
        """Gets the actions of this TxDetailsResponse.  # noqa: E501


        :return: The actions of this TxDetailsResponse.  # noqa: E501
        :rtype: list[TxOutItem]
        """
        return self._actions

    @actions.setter
    def actions(self, actions):
        """Sets the actions of this TxDetailsResponse.


        :param actions: The actions of this TxDetailsResponse.  # noqa: E501
        :type: list[TxOutItem]
        """

        self._actions = actions

    @property
    def out_txs(self):
        """Gets the out_txs of this TxDetailsResponse.  # noqa: E501


        :return: The out_txs of this TxDetailsResponse.  # noqa: E501
        :rtype: list[Tx]
        """
        return self._out_txs

    @out_txs.setter
    def out_txs(self, out_txs):
        """Sets the out_txs of this TxDetailsResponse.


        :param out_txs: The out_txs of this TxDetailsResponse.  # noqa: E501
        :type: list[Tx]
        """

        self._out_txs = out_txs

    @property
    def consensus_height(self):
        """Gets the consensus_height of this TxDetailsResponse.  # noqa: E501

        the thorchain height at which the inbound reached consensus  # noqa: E501

        :return: The consensus_height of this TxDetailsResponse.  # noqa: E501
        :rtype: int
        """
        return self._consensus_height

    @consensus_height.setter
    def consensus_height(self, consensus_height):
        """Sets the consensus_height of this TxDetailsResponse.

        the thorchain height at which the inbound reached consensus  # noqa: E501

        :param consensus_height: The consensus_height of this TxDetailsResponse.  # noqa: E501
        :type: int
        """

        self._consensus_height = consensus_height

    @property
    def finalised_height(self):
        """Gets the finalised_height of this TxDetailsResponse.  # noqa: E501

        the thorchain height at which the outbound was finalised  # noqa: E501

        :return: The finalised_height of this TxDetailsResponse.  # noqa: E501
        :rtype: int
        """
        return self._finalised_height

    @finalised_height.setter
    def finalised_height(self, finalised_height):
        """Sets the finalised_height of this TxDetailsResponse.

        the thorchain height at which the outbound was finalised  # noqa: E501

        :param finalised_height: The finalised_height of this TxDetailsResponse.  # noqa: E501
        :type: int
        """

        self._finalised_height = finalised_height

    @property
    def updated_vault(self):
        """Gets the updated_vault of this TxDetailsResponse.  # noqa: E501


        :return: The updated_vault of this TxDetailsResponse.  # noqa: E501
        :rtype: bool
        """
        return self._updated_vault

    @updated_vault.setter
    def updated_vault(self, updated_vault):
        """Sets the updated_vault of this TxDetailsResponse.


        :param updated_vault: The updated_vault of this TxDetailsResponse.  # noqa: E501
        :type: bool
        """

        self._updated_vault = updated_vault

    @property
    def reverted(self):
        """Gets the reverted of this TxDetailsResponse.  # noqa: E501


        :return: The reverted of this TxDetailsResponse.  # noqa: E501
        :rtype: bool
        """
        return self._reverted

    @reverted.setter
    def reverted(self, reverted):
        """Sets the reverted of this TxDetailsResponse.


        :param reverted: The reverted of this TxDetailsResponse.  # noqa: E501
        :type: bool
        """

        self._reverted = reverted

    @property
    def outbound_height(self):
        """Gets the outbound_height of this TxDetailsResponse.  # noqa: E501

        the thorchain height for which the outbound was scheduled  # noqa: E501

        :return: The outbound_height of this TxDetailsResponse.  # noqa: E501
        :rtype: int
        """
        return self._outbound_height

    @outbound_height.setter
    def outbound_height(self, outbound_height):
        """Sets the outbound_height of this TxDetailsResponse.

        the thorchain height for which the outbound was scheduled  # noqa: E501

        :param outbound_height: The outbound_height of this TxDetailsResponse.  # noqa: E501
        :type: int
        """

        self._outbound_height = outbound_height

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TxDetailsResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TxDetailsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RUNEPoolResponseProviders(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'units': 'str',
        'pending_units': 'str',
        'pending_rune': 'str',
        'value': 'str',
        'pnl': 'str',
        'current_deposit': 'str'
    }

    attribute_map = {
        'units': 'units',
        'pending_units': 'pending_units',
        'pending_rune': 'pending_rune',
        'value': 'value',
        'pnl': 'pnl',
        'current_deposit': 'current_deposit'
    }

    def __init__(self, units=None, pending_units=None, pending_rune=None, value=None, pnl=None, current_deposit=None):  # noqa: E501
        """RUNEPoolResponseProviders - a model defined in Swagger"""  # noqa: E501
        self._units = None
        self._pending_units = None
        self._pending_rune = None
        self._value = None
        self._pnl = None
        self._current_deposit = None
        self.discriminator = None
        self.units = units
        self.pending_units = pending_units
        self.pending_rune = pending_rune
        self.value = value
        self.pnl = pnl
        self.current_deposit = current_deposit

    @property
    def units(self):
        """Gets the units of this RUNEPoolResponseProviders.  # noqa: E501

        the units of RUNEPool owned by providers (including pending)  # noqa: E501

        :return: The units of this RUNEPoolResponseProviders.  # noqa: E501
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this RUNEPoolResponseProviders.

        the units of RUNEPool owned by providers (including pending)  # noqa: E501

        :param units: The units of this RUNEPoolResponseProviders.  # noqa: E501
        :type: str
        """
        if units is None:
            raise ValueError("Invalid value for `units`, must not be `None`")  # noqa: E501

        self._units = units

    @property
    def pending_units(self):
        """Gets the pending_units of this RUNEPoolResponseProviders.  # noqa: E501

        the units of RUNEPool owned by providers that remain pending  # noqa: E501

        :return: The pending_units of this RUNEPoolResponseProviders.  # noqa: E501
        :rtype: str
        """
        return self._pending_units

    @pending_units.setter
    def pending_units(self, pending_units):
        """Sets the pending_units of this RUNEPoolResponseProviders.

        the units of RUNEPool owned by providers that remain pending  # noqa: E501

        :param pending_units: The pending_units of this RUNEPoolResponseProviders.  # noqa: E501
        :type: str
        """
        if pending_units is None:
            raise ValueError("Invalid value for `pending_units`, must not be `None`")  # noqa: E501

        self._pending_units = pending_units

    @property
    def pending_rune(self):
        """Gets the pending_rune of this RUNEPoolResponseProviders.  # noqa: E501

        the amount of RUNE pending  # noqa: E501

        :return: The pending_rune of this RUNEPoolResponseProviders.  # noqa: E501
        :rtype: str
        """
        return self._pending_rune

    @pending_rune.setter
    def pending_rune(self, pending_rune):
        """Sets the pending_rune of this RUNEPoolResponseProviders.

        the amount of RUNE pending  # noqa: E501

        :param pending_rune: The pending_rune of this RUNEPoolResponseProviders.  # noqa: E501
        :type: str
        """
        if pending_rune is None:
            raise ValueError("Invalid value for `pending_rune`, must not be `None`")  # noqa: E501

        self._pending_rune = pending_rune

    @property
    def value(self):
        """Gets the value of this RUNEPoolResponseProviders.  # noqa: E501

        the value of the provider share of the RUNEPool (includes pending RUNE)  # noqa: E501

        :return: The value of this RUNEPoolResponseProviders.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this RUNEPoolResponseProviders.

        the value of the provider share of the RUNEPool (includes pending RUNE)  # noqa: E501

        :param value: The value of this RUNEPoolResponseProviders.  # noqa: E501
        :type: str
        """
        if value is None:
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def pnl(self):
        """Gets the pnl of this RUNEPoolResponseProviders.  # noqa: E501

        the profit and loss of the provider share of the RUNEPool  # noqa: E501

        :return: The pnl of this RUNEPoolResponseProviders.  # noqa: E501
        :rtype: str
        """
        return self._pnl

    @pnl.setter
    def pnl(self, pnl):
        """Sets the pnl of this RUNEPoolResponseProviders.

        the profit and loss of the provider share of the RUNEPool  # noqa: E501

        :param pnl: The pnl of this RUNEPoolResponseProviders.  # noqa: E501
        :type: str
        """
        if pnl is None:
            raise ValueError("Invalid value for `pnl`, must not be `None`")  # noqa: E501

        self._pnl = pnl

    @property
    def current_deposit(self):
        """Gets the current_deposit of this RUNEPoolResponseProviders.  # noqa: E501

        the current RUNE deposited by providers  # noqa: E501

        :return: The current_deposit of this RUNEPoolResponseProviders.  # noqa: E501
        :rtype: str
        """
        return self._current_deposit

    @current_deposit.setter
    def current_deposit(self, current_deposit):
        """Sets the current_deposit of this RUNEPoolResponseProviders.

        the current RUNE deposited by providers  # noqa: E501

        :param current_deposit: The current_deposit of this RUNEPoolResponseProviders.  # noqa: E501
        :type: str
        """
        if current_deposit is None:
            raise ValueError("Invalid value for `current_deposit`, must not be `None`")  # noqa: E501

        self._current_deposit = current_deposit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RUNEPoolResponseProviders, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RUNEPoolResponseProviders):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BanResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'node_address': 'str',
        'block_height': 'int',
        'signers': 'list[str]'
    }

    attribute_map = {
        'node_address': 'node_address',
        'block_height': 'block_height',
        'signers': 'signers'
    }

    def __init__(self, node_address=None, block_height=None, signers=None):  # noqa: E501
        """BanResponse - a model defined in Swagger"""  # noqa: E501
        self._node_address = None
        self._block_height = None
        self._signers = None
        self.discriminator = None
        if node_address is not None:
            self.node_address = node_address
        if block_height is not None:
            self.block_height = block_height
        if signers is not None:
            self.signers = signers

    @property
    def node_address(self):
        """Gets the node_address of this BanResponse.  # noqa: E501


        :return: The node_address of this BanResponse.  # noqa: E501
        :rtype: str
        """
        return self._node_address

    @node_address.setter
    def node_address(self, node_address):
        """Sets the node_address of this BanResponse.


        :param node_address: The node_address of this BanResponse.  # noqa: E501
        :type: str
        """

        self._node_address = node_address

    @property
    def block_height(self):
        """Gets the block_height of this BanResponse.  # noqa: E501


        :return: The block_height of this BanResponse.  # noqa: E501
        :rtype: int
        """
        return self._block_height

    @block_height.setter
    def block_height(self, block_height):
        """Sets the block_height of this BanResponse.


        :param block_height: The block_height of this BanResponse.  # noqa: E501
        :type: int
        """

        self._block_height = block_height

    @property
    def signers(self):
        """Gets the signers of this BanResponse.  # noqa: E501


        :return: The signers of this BanResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._signers

    @signers.setter
    def signers(self, signers):
        """Sets the signers of this BanResponse.


        :param signers: The signers of this BanResponse.  # noqa: E501
        :type: list[str]
        """

        self._signers = signers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BanResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BanResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TxResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'observed_tx': 'ObservedTx',
        'consensus_height': 'int',
        'finalised_height': 'int',
        'outbound_height': 'int',
        'keysign_metric': 'TssKeysignMetric'
    }

    attribute_map = {
        'observed_tx': 'observed_tx',
        'consensus_height': 'consensus_height',
        'finalised_height': 'finalised_height',
        'outbound_height': 'outbound_height',
        'keysign_metric': 'keysign_metric'
    }

    def __init__(self, observed_tx=None, consensus_height=None, finalised_height=None, outbound_height=None, keysign_metric=None):  # noqa: E501
        """TxResponse - a model defined in Swagger"""  # noqa: E501
        self._observed_tx = None
        self._consensus_height = None
        self._finalised_height = None
        self._outbound_height = None
        self._keysign_metric = None
        self.discriminator = None
        if observed_tx is not None:
            self.observed_tx = observed_tx
        if consensus_height is not None:
            self.consensus_height = consensus_height
        if finalised_height is not None:
            self.finalised_height = finalised_height
        if outbound_height is not None:
            self.outbound_height = outbound_height
        if keysign_metric is not None:
            self.keysign_metric = keysign_metric

    @property
    def observed_tx(self):
        """Gets the observed_tx of this TxResponse.  # noqa: E501


        :return: The observed_tx of this TxResponse.  # noqa: E501
        :rtype: ObservedTx
        """
        return self._observed_tx

    @observed_tx.setter
    def observed_tx(self, observed_tx):
        """Sets the observed_tx of this TxResponse.


        :param observed_tx: The observed_tx of this TxResponse.  # noqa: E501
        :type: ObservedTx
        """

        self._observed_tx = observed_tx

    @property
    def consensus_height(self):
        """Gets the consensus_height of this TxResponse.  # noqa: E501

        the thorchain height at which the inbound reached consensus  # noqa: E501

        :return: The consensus_height of this TxResponse.  # noqa: E501
        :rtype: int
        """
        return self._consensus_height

    @consensus_height.setter
    def consensus_height(self, consensus_height):
        """Sets the consensus_height of this TxResponse.

        the thorchain height at which the inbound reached consensus  # noqa: E501

        :param consensus_height: The consensus_height of this TxResponse.  # noqa: E501
        :type: int
        """

        self._consensus_height = consensus_height

    @property
    def finalised_height(self):
        """Gets the finalised_height of this TxResponse.  # noqa: E501

        the thorchain height at which the outbound was finalised  # noqa: E501

        :return: The finalised_height of this TxResponse.  # noqa: E501
        :rtype: int
        """
        return self._finalised_height

    @finalised_height.setter
    def finalised_height(self, finalised_height):
        """Sets the finalised_height of this TxResponse.

        the thorchain height at which the outbound was finalised  # noqa: E501

        :param finalised_height: The finalised_height of this TxResponse.  # noqa: E501
        :type: int
        """

        self._finalised_height = finalised_height

    @property
    def outbound_height(self):
        """Gets the outbound_height of this TxResponse.  # noqa: E501

        the thorchain height for which the outbound was scheduled  # noqa: E501

        :return: The outbound_height of this TxResponse.  # noqa: E501
        :rtype: int
        """
        return self._outbound_height

    @outbound_height.setter
    def outbound_height(self, outbound_height):
        """Sets the outbound_height of this TxResponse.

        the thorchain height for which the outbound was scheduled  # noqa: E501

        :param outbound_height: The outbound_height of this TxResponse.  # noqa: E501
        :type: int
        """

        self._outbound_height = outbound_height

    @property
    def keysign_metric(self):
        """Gets the keysign_metric of this TxResponse.  # noqa: E501


        :return: The keysign_metric of this TxResponse.  # noqa: E501
        :rtype: TssKeysignMetric
        """
        return self._keysign_metric

    @keysign_metric.setter
    def keysign_metric(self, keysign_metric):
        """Sets the keysign_metric of this TxResponse.


        :param keysign_metric: The keysign_metric of this TxResponse.  # noqa: E501
        :type: TssKeysignMetric
        """

        self._keysign_metric = keysign_metric

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TxResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TxResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class VaultPubkeysResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asgard': 'list[VaultInfo]',
        'yggdrasil': 'list[VaultInfo]',
        'inactive': 'list[VaultInfo]'
    }

    attribute_map = {
        'asgard': 'asgard',
        'yggdrasil': 'yggdrasil',
        'inactive': 'inactive'
    }

    def __init__(self, asgard=None, yggdrasil=None, inactive=None):  # noqa: E501
        """VaultPubkeysResponse - a model defined in Swagger"""  # noqa: E501
        self._asgard = None
        self._yggdrasil = None
        self._inactive = None
        self.discriminator = None
        self.asgard = asgard
        self.yggdrasil = yggdrasil
        self.inactive = inactive

    @property
    def asgard(self):
        """Gets the asgard of this VaultPubkeysResponse.  # noqa: E501


        :return: The asgard of this VaultPubkeysResponse.  # noqa: E501
        :rtype: list[VaultInfo]
        """
        return self._asgard

    @asgard.setter
    def asgard(self, asgard):
        """Sets the asgard of this VaultPubkeysResponse.


        :param asgard: The asgard of this VaultPubkeysResponse.  # noqa: E501
        :type: list[VaultInfo]
        """
        if asgard is None:
            raise ValueError("Invalid value for `asgard`, must not be `None`")  # noqa: E501

        self._asgard = asgard

    @property
    def yggdrasil(self):
        """Gets the yggdrasil of this VaultPubkeysResponse.  # noqa: E501


        :return: The yggdrasil of this VaultPubkeysResponse.  # noqa: E501
        :rtype: list[VaultInfo]
        """
        return self._yggdrasil

    @yggdrasil.setter
    def yggdrasil(self, yggdrasil):
        """Sets the yggdrasil of this VaultPubkeysResponse.


        :param yggdrasil: The yggdrasil of this VaultPubkeysResponse.  # noqa: E501
        :type: list[VaultInfo]
        """
        if yggdrasil is None:
            raise ValueError("Invalid value for `yggdrasil`, must not be `None`")  # noqa: E501

        self._yggdrasil = yggdrasil

    @property
    def inactive(self):
        """Gets the inactive of this VaultPubkeysResponse.  # noqa: E501


        :return: The inactive of this VaultPubkeysResponse.  # noqa: E501
        :rtype: list[VaultInfo]
        """
        return self._inactive

    @inactive.setter
    def inactive(self, inactive):
        """Sets the inactive of this VaultPubkeysResponse.


        :param inactive: The inactive of this VaultPubkeysResponse.  # noqa: E501
        :type: list[VaultInfo]
        """
        if inactive is None:
            raise ValueError("Invalid value for `inactive`, must not be `None`")  # noqa: E501

        self._inactive = inactive

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VaultPubkeysResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VaultPubkeysResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InvariantResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'invariant': 'str',
        'broken': 'bool',
        'msg': 'list[str]'
    }

    attribute_map = {
        'invariant': 'invariant',
        'broken': 'broken',
        'msg': 'msg'
    }

    def __init__(self, invariant=None, broken=None, msg=None):  # noqa: E501
        """InvariantResponse - a model defined in Swagger"""  # noqa: E501
        self._invariant = None
        self._broken = None
        self._msg = None
        self.discriminator = None
        self.invariant = invariant
        self.broken = broken
        self.msg = msg

    @property
    def invariant(self):
        """Gets the invariant of this InvariantResponse.  # noqa: E501

        The name of the invariant.  # noqa: E501

        :return: The invariant of this InvariantResponse.  # noqa: E501
        :rtype: str
        """
        return self._invariant

    @invariant.setter
    def invariant(self, invariant):
        """Sets the invariant of this InvariantResponse.

        The name of the invariant.  # noqa: E501

        :param invariant: The invariant of this InvariantResponse.  # noqa: E501
        :type: str
        """
        if invariant is None:
            raise ValueError("Invalid value for `invariant`, must not be `None`")  # noqa: E501

        self._invariant = invariant

    @property
    def broken(self):
        """Gets the broken of this InvariantResponse.  # noqa: E501

        Returns true if the invariant is broken.  # noqa: E501

        :return: The broken of this InvariantResponse.  # noqa: E501
        :rtype: bool
        """
        return self._broken

    @broken.setter
    def broken(self, broken):
        """Sets the broken of this InvariantResponse.

        Returns true if the invariant is broken.  # noqa: E501

        :param broken: The broken of this InvariantResponse.  # noqa: E501
        :type: bool
        """
        if broken is None:
            raise ValueError("Invalid value for `broken`, must not be `None`")  # noqa: E501

        self._broken = broken

    @property
    def msg(self):
        """Gets the msg of this InvariantResponse.  # noqa: E501

        Informative message about the invariant result.  # noqa: E501

        :return: The msg of this InvariantResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._msg

    @msg.setter
    def msg(self, msg):
        """Sets the msg of this InvariantResponse.

        Informative message about the invariant result.  # noqa: E501

        :param msg: The msg of this InvariantResponse.  # noqa: E501
        :type: list[str]
        """
        if msg is None:
            raise ValueError("Invalid value for `msg`, must not be `None`")  # noqa: E501

        self._msg = msg

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InvariantResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvariantResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
